{% extends "admin/base_site.html" %}
{% load i18n %}

{% block breadcrumbs-relative %}<li><a href="../../">{% trans 'Admin' %}</a></li><li class='last'>{% trans 'Password reset' %}</li>{% endblock %}

{% block title %}{% trans "Password reset" %}{% endblock %}

{% block content %}

<p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>

<form action="" method="post">{% csrf_token %}
{{ form.email.errors }}
<p><label for="id_email">{% trans 'E-mail address:' %}</label> {{ form.email }} <input type="submit" value="{% trans 'Reset my password' %}" /></p>
</form>

{% endblock %}
