{% extends "admin/base.html" %}
{% load i18n %}
{% load adminmedia %}

{% block title %}{% if not is_popup %}{{ title }} | {% trans SITE_NAME %}{% endif %}{% endblock %}

{% block branding %}
<h1>{% trans 'EPFL admin' %}</h1>
{% endblock %}

{% block nav-global %}{% endblock %}
