{% extends "admin/index.html" %} 
{% load i18n %} 

{% comment %}{% if not is_popup %}{% endcomment %}

	{% block breadcrumbs-relative %}
		<li><a href="/admin/">
		{% trans "Admin" %}</a></li> 
		
		{% for app in app_list %}
			<li class='last'>
				{% blocktrans with app.name as name %}{{ name }}{% endblocktrans %}
			</li>
		{% endfor %}
	
	{% endblock %}

{% comment %}{% endif %} {% endcomment %}

{% block sidebar %}{% endblock %}