    <a name="top"></a>
    <div id="accessibility" class="hidden" title="École Polytechnique Fédérale de Lausanne - Quick access">
      <ul>
        <li><a href="http://www.epfl.ch/accessibility.en.shtml" title="Specific informations for persons with disabilities" accesskey="0">Accessibility</a></li>
        <li><a href="http://www.epfl.ch/" title="EPFL's homepage"  accesskey="1">Homepage</a></li>
        <li><a href="#navigation" accesskey="2">Navigation within EPFL sites</a></li>
        <li><a href="#main-navigation" accesskey="3">Navigation within this site</a></li>
        <li><a href="#search" id="searchlink" accesskey="4">Jump to search field</a></li>
        <li><a href="#content" accesskey="5">Jump to page content</a></li>
        <li><a href="mailto:webmaster@epfl.ch" accesskey="9">Technical contact</a></li>
      </ul>
    </div>
    <div id="header">
      <div id="nav-logo"><a href="http://www.epfl.ch" title="EPFL's homepage"></a></div>
      <div id="nav-menus">
        <a name="navigation" id="navigation"></a>
        <ul id="main-menus">
          <li class="portal menu" id="public-menu-link">
            <a class="main-link" href="http://www.epfl.ch/navigate.en.shtml" title="Navigate by profile">You are</a>
            <div class="navigation-panel hidden" id="public-panel">
              <ul>
                <li class="group-2-cols">
                  <h3><a href="http://futuretudiant.epfl.ch/page-21078-en.html">Prospective students portal</a></h3>
                  <ul>
                    <li><a href="http://www.epfl.ch/epfl-virtual-tour/virtual-tour.html">EPFL Virtual tour</a></li>
                    <li><a href="http://sae.epfl.ch/page-27094-en.html">Exchange student</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://studying.epfl.ch/page-8529-en.html">Students portal</a></h3>
                  <ul>
                    <li><a href="http://studying.epfl.ch/student_desk">Student services</a></li>
                    <li><a href="http://sac.epfl.ch/academic-calendar">Academic calendar</a></li>
                  </ul>
                </li>
                <li class="group-2-cols last">
                  <h3><a href="http://recherche.epfl.ch/page-36159-en.html">Researchers portal</a></h3>
                  <ul>
                    <li><a href="http://grantsoffice.epfl.ch/">Research funding</a></li>
                    <li><a href="http://phd.epfl.ch/page-19491-en.html">Doctorate at EPFL</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://working.epfl.ch/staff-portal">Staff portal</a></h3>
                  <ul>
                    <li><a href="http://rh.epfl.ch">Human resources</a></li>
                    <li><a href="http://help.epfl.ch/help">Help</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://entreprises.epfl.ch/page57580-en.html">Business portal</a></h3>
                  <ul>
                    <li><a href="http://vpiv.epfl.ch/page-22990-en.html">Innovation &amp; Tech Transfer</a></li>
                    <li><a href="http://vpiv.epfl.ch/page-23023-en.html">Innovation Square</a></li>
                  </ul>
                </li>
                <li class="group-2-cols last">
                  <h3><a href="http://medias.epfl.ch/page-33838-en.html">Mediacorner</a></h3>
                  <ul>
                    <li><a href="http://medias.epfl.ch/press-releases">Press releases</a>, <a href="http://medias.epfl.ch/page-41720-en.html">Reflex</a>, <a href="http://actualites.epfl.ch/index.php?module=Newspaper&amp;func=viewalleditions">Flash</a></li>
                    <li><a href="http://mediatheque.epfl.ch/">Image library</a></li>
                  </ul>
                </li><li class="group-2-cols">
                  <h3><a href="http://teaching.epfl.ch/page-16682-en.html">Teaching portal</a></h3>
                  <ul>
                    <li><a href="http://teaching.epfl.ch/page-53543-en.html">Courses management</a></li>
                    <li><a href="http://teaching.epfl.ch/page-16697-en.html">Students management</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://a3.epfl.ch/">Alumni Portal</a></h3>
                  <ul>
                    <li><a href="http://www.epflalumni.ch/page/devenir-membre-1">Become a member</a></li>
                    <li><a href="http://www.epflalumni.ch/events">A3 agenda</a></li>
                  </ul>
                </li>
              </ul>
              <div class="clear"></div>
            </div>
          </li>
          <li class="school menu" id="school-menu-link">
            <a class="main-link" href="http://www.epfl.ch/navigate.en.shtml" title="Navigate by school"><span>By</span> school</a>
            <div class="navigation-panel hidden" id="school-panel">
              <ul>
                <li class="group-2-cols">
                  <h3><a href="http://enac.epfl.ch/page-1922-en.html" class="enac">Architecture, Civil and Environmental Engineering <acronym title="Environnement Naturel, Architectural et Construit">ENAC</acronym></a></h3>
                  <ul>
                    <li><a href="http://enac.epfl.ch/page-2444-en.html">Architecture</a></li>
                    <li><a href="http://enac.epfl.ch/page-2445-en.html">Civil Engineering</a></li>
                    <li><a href="http://enac.epfl.ch/page-2446-en.html">Environmental Engineering</a></li>
                    <li><a href="http://enac.epfl.ch/page-2447-en.html">Urban Planning</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://sb.epfl.ch/page-2902-en.html" class="sb">Basic Sciences <acronym title="Sciences de Base">SB</acronym></a></h3>
                  <ul>
                    <li><a href="http://sb.epfl.ch/chemistry">Chemistry</a></li>
                    <li><a href="http://sb.epfl.ch/mathematics">Mathematics</a></li>
                    <li><a href="http://sb.epfl.ch/physics">Physics</a></li>
                  </ul>
                </li>
                <li class="group-2-cols last">
                  <h3><a href="http://sti.epfl.ch/page-1541-en.html" class="sti">Engineering <acronym title="Sciences et Techniques de l'Ingénieur">STI</acronym></a></h3>
                  <ul>
                    <li><a href="http://sti.epfl.ch/page-1545-en.html">Electrical Engineering</a></li>
                    <li><a href="http://sti.epfl.ch/page-1592-en.html">Mechanical Engineering</a></li>
                    <li><a href="http://sti.epfl.ch/page-1617-en.html">Materials Science and Engineering</a></li>
                    <li><a href="http://sti.epfl.ch/page-1674-en.html">Microengineering</a></li>
                    <li><a href="http://ibi.epfl.ch/">Bioengineering</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://ic.epfl.ch/page-5735-en.html" class="ic">Computer &amp; Communication Sciences <acronym title="Informatique &amp; Communications">I&amp;C</acronym></a></h3>
                  <ul>
                    <li><a href="http://ic.epfl.ch/computer-science">Computer Science</a></li>
                    <li><a href="http://ic.epfl.ch/communication-systems">Communication Systems</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://sv.epfl.ch/" class="sv">Life Sciences <acronym title="Sciences de la Vie">SV</acronym></a></h3>
                  <ul>
                    <li><a href="http://sv.epfl.ch/page-37989.html">Bioengineering</a></li>
                    <li><a href="http://sv.epfl.ch/page-26599.html">Neuroscience Brain Mind &amp; Blue Brain</a></li>
                    <li><a href="http://sv.epfl.ch/page-37990.html">Global Health</a></li>
                    <li><a href="http://sv.epfl.ch/page-37991.html">Cancer</a></li>
                  </ul>
                </li>
                <li class="group-2-cols last">
                  <h3><a href="http://cdm.epfl.ch/homepage" class="cdm">Management of Technology <acronym title="Collège du Management de la Technologie">CDM</acronym></a></h3>
                  <ul>
                    <li><a href="http://mtei.epfl.ch">Management of Technology</a></li>
                    <li><a href="http://sfi.epfl.ch">Financial Engineering</a></li>
                  </ul>
                </li>
                <li class="group-2-cols" style="clear:left">
                  <h3><a href="http://cdh.epfl.ch/page-1543-en.html" class="cdh">College of Humanities <acronym title="Collège des Humanités">CDH</acronym></a></h3>
                  <ul>
                    <li><a href="http://cdh.epfl.ch/page-37081-en.html">Human and Social Science</a></li>
                    <li><a href="http://cdh.epfl.ch/page-25502-en.html">Area &amp; Cultural Studies</a></li>
                    <li><a href="http://cdh.epfl.ch/ontology">Center for Social Ontology</a></li>
                  </ul>
                </li>
              </ul>
              <div class="clear"></div>
            </div>
          </li>
          <li class="short menu" id="brief-menu-link">
            <a class="main-link" href="http://www.epfl.ch/navigate.en.shtml"><span>about</span> <acronym title="École Polytechnique Fédérale de Lausanne">EPFL</acronym></a>
            <div class="navigation-panel hidden" id="brief-panel">
              <ul>
                <li class="group-2-cols">
                  <h3><a href="http://information.epfl.ch/page-16430-en.html"><acronym title="École Polytechnique Fédérale de Lausanne">EPFL</acronym></a></h3>
                  <ul>
                    <li><a href="http://direction.epfl.ch/page-30791-en.html">Direction</a></li>
                    <li><a href="http://www.epfl.ch/organigrammes">EPFL Structure</a></li>
                    <li><a href="http://information.epfl.ch/">General information</a></li>
                    <li><a href="http://library.epfl.ch/">Library</a></li>
                    <li><a href="http://emploi.epfl.ch/page-31605-en.html">Job offers</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://futuretudiant.epfl.ch/page-21078-en.html">Education</a></h3>
                  <ul>
                    <li><a href="http://cms.epfl.ch/">Preparatory course <acronym title="Cours de Mathématiques Spéciales">CMS</acronym></a></li>
                    <li><a href="http://bachelor.epfl.ch/studies">Bachelor</a></li>
                    <li><a href="http://master.epfl.ch/page-21270-en.html">Master</a></li>
                    <li><a href="http://phd.epfl.ch/page-19488-en.html">PhD</a></li>
                    <li><a href="http://www.formation-continue-unil-epfl.ch/en">Continuing education</a> (EPFL-UNIL Foundation)</li>
                  </ul>
                </li>
                <li class="group-2-cols last">
                  <h3><a href="http://recherche.epfl.ch/page-36159-en.html">Research</a></h3>
                  <ul>
                    <li><a href="http://vpiv.epfl.ch/page-22996-en.html">Transdisciplinary Centers</a></li>
                    <li><a href="http://grantsoffice.epfl.ch/">Grants office</a></li>
                    <li><a href="http://commission-recherche.epfl.ch/page-25053-en.html">Research Commission</a></li>
                    <li><a href="http://infoscience.epfl.ch/?ln=en"><acronym title="École Polytechnique Fédérale de Lausanne">EPFL</acronym> Publications</a></li>
                  </ul>
                </li>
                <li class="group-2-cols" style="clear: left;">
                  <h3><a href="http://vpiv.epfl.ch/page-22990-en.html">Innovation &amp; Tech Transfer</a></h3>
                  <ul>
                    <li><a href="http://vpiv.epfl.ch/page-22997-en.html">Partnerships</a></li>
                    <li><a href="http://vpiv.epfl.ch/page-22998-en.html">Start-up</a></li>
                    <li><a href="http://www.alliance-tt.ch">Industrial liaison</a></li>
                    <li><a href="http://sri.epfl.ch/">Technology transfer, patents</a></li>
                  </ul>
                </li>
                <li class="group-2-cols">
                  <h3><a href="http://international.epfl.ch/page-42781-en.html">International portal</a></h3>
                  <ul>
                    <li><a href="http://daia.epfl.ch/page-21112-en.html">International Relations</a></li>
                    <li><a href="http://www.epfl.ae">EPFL Middle East</a></li>
                    <li><a href="http://cooperation.epfl.ch/page-8942-en.html">Cooperation</a></li>
                  </ul>
                </li>
              </ul>
              <div class="clear"></div>
            </div>
          </li>
        </ul>
      </div>

      <div class="local-color" id="nav-search">
        <div id="search-box">
          <a name="search"></a>
          <form name="search" action="http://search.epfl.ch/process_web2010" id="searchform">
            <input class="hidden" type="radio" name="engine" id="search-engine-person" value="person" checked="checked" title="Find a person" />
            <label for="search-engine-person" class="current" title="Find a person">Person</label>
            <input class="hidden" type="radio" name="engine" id="search-engine-place" value="place" title="Find a place"/>
            <label for="search-engine-place" title="Find a place">Place</label>
            <input class="hidden" type="radio" name="engine" id="search-engine-epfl" value="epfl" title="Search within EPFL sites"/>
            <label for="search-engine-epfl" title="Search within EPFL sites"><acronym title="École Polytechnique Fédérale de Lausanne">EPFL</acronym> Web</label>
            <input class="hidden" type="radio" name="engine" id="search-engine-local" value="local"  title="Search within this site"/>
            <label for="search-engine-local" title="Search within this site">On this site</label>
            <input type="hidden" name="lang" value="en" />
            <input type="text" class="search" name="q" value="" id="searchfield" /><button type="submit" class="search-button"  title="Search">Search</button>
          </form>
        </div>
      </div>
      <div class="clear"></div>
    </div>